@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: LGPL-3.0-or-later */
 /*
  * Copyright © 2012-2014, CohortFS, LLC.
  * Author: Adam C. Emerson <aemerson@linuxbox.com>
@@ -136,9 +137,9 @@ struct ceph_handle {
  */
 
 struct ds_wire {
-	struct wire_handle wire; /*< All the information of a regualr handle */
+	struct wire_handle wire; /*< All the information of a regular handle */
 	struct ceph_file_layout layout;	/*< Layout information */
-	uint64_t snapseq; /*< And a single entry giving a degernate
+	uint64_t snapseq; /*< And a single entry giving a degenerate
 			      snaprealm. */
 };
 
@@ -155,12 +156,22 @@ struct ds {
 
 #endif				/* CEPH_PNFS */
 
-#define CEPH_SUPPORTED_ATTRS ((const attrmask_t) (ATTRS_POSIX|ATTR4_SEC_LABEL))
+#ifdef CEPHFS_POSIX_ACL
+#  define POSIX_ACL_ATTR	ATTR_ACL
+#else /* CEPHFS_POSIX_ACL */
+#  define POSIX_ACL_ATTR	0
+#endif /* CEPHFS_POSIX_ACL */
 
-#define CEPH_SETTABLE_ATTRIBUTES ((const attrmask_t) (			\
-	ATTR_MODE  | ATTR_OWNER | ATTR_GROUP | ATTR_ATIME	 |	\
-	ATTR_CTIME | ATTR_MTIME | ATTR_SIZE  | ATTR_MTIME_SERVER |	\
-	ATTR_ATIME_SERVER | ATTR4_SEC_LABEL))
+#define CEPH_SUPPORTED_ATTRS ((const attrmask_t) (ATTRS_POSIX |		\
+						  ATTR4_SEC_LABEL |	\
+						  ATTR4_XATTR |		\
+						  POSIX_ACL_ATTR	\
+						  ))
+
+#define CEPH_SETTABLE_ATTRIBUTES ((const attrmask_t) (          \
+	ATTR_MODE  | ATTR_OWNER | ATTR_GROUP | ATTR_ATIME    |  \
+	ATTR_CTIME | ATTR_MTIME | ATTR_SIZE  | ATTR_MTIME_SERVER |  \
+	ATTR_ATIME_SERVER | ATTR4_SEC_LABEL | POSIX_ACL_ATTR))
 
 /* Prototypes */
 
@@ -188,7 +199,7 @@ static inline fsal_status_t ceph2fsal_error(const int ceph_errorcode)
 
 unsigned int attrmask2ceph_want(attrmask_t mask);
 void ceph2fsal_attributes(const struct ceph_statx *stx,
-			  struct attrlist *fsalattr);
+			  struct fsal_attrlist *fsalattr);
 
 void export_ops_init(struct export_ops *ops);
 void handle_ops_init(struct fsal_obj_ops *ops);
@@ -204,4 +215,12 @@ struct state_t *ceph_alloc_state(struct fsal_export *exp_hdl,
 
 void ceph_free_state(struct fsal_export *exp_hdl, struct state_t *state);
 
+#ifdef CEPHFS_POSIX_ACL
+fsal_status_t ceph_set_acl(struct ceph_export *export,
+			   struct ceph_handle *objhandle, bool is_dir,
+			   struct fsal_attrlist *attrs);
+
+int ceph_get_acl(struct ceph_export *export, struct ceph_handle *objhandle,
+	bool is_dir, struct fsal_attrlist *attrs);
+#endif				/* CEPHFS_POSIX_ACL */
 #endif				/* !FSAL_CEPH_INTERNAL_INTERNAL__ */
