@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * vim:shiftwidth=8:tabstop=8:
  *
@@ -45,7 +46,7 @@
 /* defined the set of attributes supported with POSIX */
 #define MEM_SUPPORTED_ATTRIBUTES (ATTRS_POSIX)
 
-const char memname[] = "MEM";
+static const char memname[] = "MEM";
 
 /* my module private storage */
 struct mem_fsal_module MEM = {
