@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * Copyright © Red Hat, 2015
  * Author: ORit Wasserman <owasserm@redhat.com>
@@ -25,7 +26,7 @@
  * @brief Internal definitions for the RGW FSAL
  *
  * This file includes internal function definitions, constants, and
- * variable declarations used to impelment the RGW FSAL, but not
+ * variable declarations used to implement the RGW FSAL, but not
  * exposed as part of the API.
  */
 
@@ -88,7 +89,7 @@ fsal_status_t rgw2fsal_error(const int rgw_errorcode)
 	case EBADF:
 		/**
 		 * @todo: The EBADF error also happens when file is
-		 *	  opened for reading, and we try writting in
+		 *	  opened for reading, and we try writing in
 		 *	  it.  In this case, we return
 		 *	  ERR_FSAL_NOT_OPENED, but it doesn't seems to
 		 *	  be a correct error translation.
@@ -176,7 +177,7 @@ fsal_status_t rgw2fsal_error(const int rgw_errorcode)
  * it to the export.  After this call the attributes have been filled
  * in and the handle is up-to-date and usable.
  *
- * @param[in]  export Export on which the object lives
+ * @param[in]  export The export on which the object lives
  * @param[in]  rgw_fh Concise representation of the object name,
  *                    in RGW notation
  * @param[inout] st   Object attributes
@@ -191,7 +192,7 @@ int construct_handle(struct rgw_export *export,
 		     struct rgw_handle **obj)
 
 {
-	/* Poitner to the handle under construction */
+	/* Pointer to the handle under construction */
 	struct rgw_handle *constructing = NULL;
 	*obj = NULL;
 
