@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * vim:noexpandtab:shiftwidth=8:tabstop=8:
  *
@@ -148,6 +149,7 @@ static void load_fsal_static(const char *name, void (*init)(void))
 
 void start_fsals(void)
 {
+	init_ctx_refstr();
 
 	/* .init was a long time ago... */
 	load_state = idle;
@@ -224,7 +226,7 @@ int load_fsal(const char *name,
 	LogDebug(COMPONENT_INIT, "Loading FSAL %s with %s", name, path);
 #if defined(LINUX) && !defined(SANITIZE_ADDRESS)
 	dl = dlopen(path, RTLD_NOW | RTLD_LOCAL | RTLD_DEEPBIND);
-#elif defined(FREEBSD) || defined(SANITIZE_ADDRESS)
+#elif defined(BSDBASED) || defined(SANITIZE_ADDRESS)
 	dl = dlopen(path, RTLD_NOW | RTLD_LOCAL);
 #endif
 
@@ -322,7 +324,7 @@ errout:
  * must be done before using any methods.  Once done, release it with
  * @c put_fsal.
  *
- * @param[in] name Name to look up
+ * @param[in] name The name to look up
  *
  * @return Module pointer or NULL if not found.
  */
@@ -440,7 +442,7 @@ int register_fsal(struct fsal_module *fsal_hdl, const char *name,
 }
 
 /**
- * @brief Unregisterx an FSAL
+ * @brief Unregisters an FSAL
  *
  * Verify that the fsal is not busy and release all its resources
  * owned at this level.  RW Lock is already freed.  Called from the
