@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * Copyright (C) 2012, The Linux Box Corporation
  * Copyright (c) 2012-2018 Red Hat, Inc. and/or its affiliates.
@@ -219,8 +220,7 @@ static inline void setup_client_saddr(nfs_client_id_t *clientid,
 	 * passing to inet_pton as is and will support a variety of formats.
 	 */
 
-	memset(&clientid->cid_cb.v40.cb_addr.ss, 0,
-	       sizeof(struct sockaddr_storage));
+	memset(&clientid->cid_cb.v40.cb_addr.ss, 0, sizeof(sockaddr_t));
 
 	switch (clientid->cid_cb.v40.cb_addr.nc) {
 	case _NC_TCP:
@@ -644,7 +644,7 @@ static void _nfs_rpc_destroy_chan(rpc_call_channel_t *chan)
  * Call the NFSv4 client's CB_NULL procedure.
  *
  * @param[in] chan    Channel on which to call
- * @param[in] timeout Timeout for client call
+ * @param[in] timeout The timeout for client call
  * @param[in] locked  True if the channel is already locked
  *
  * @return Client status.
@@ -962,7 +962,7 @@ static void nfs_rpc_call_process(struct clnt_req *cc)
  * @brief Dispatch a call
  *
  * @param[in,out] call  The call to dispatch
- * @param[in]     flags Flags governing call
+ * @param[in]     flags The flags governing call
  *
  * @return enum clnt_stat.
  */
@@ -1026,7 +1026,7 @@ int32_t nfs_rpc_abort_call(rpc_call_t *call)
  * This function constructs a compound with a CB_SEQUENCE and one
  * other operation.
  *
- * @param[in] session Session on whose back channel we make the call
+ * @param[in] session The session on whose back channel we make the call
  * @param[in] op      The operation to add
  * @param[in] refer   Referral data, NULL if none
  * @param[in] slot    Slot number to use
@@ -1109,7 +1109,7 @@ static void release_v41(rpc_call_t *call)
  * Find and reserve a slot, if we can.  If @c wait is set to true, we
  * wait on the condition variable for a limited time.
  *
- * @param[in,out] session      Sesson on which to operate
+ * @param[in,out] session      Session on which to operate
  * @param[in]     wait         Whether to wait on the condition variable if
  *                             no slot can be found
  * @param[out]    slot         Slot to use
@@ -1170,7 +1170,7 @@ static bool find_cb_slot(nfs41_session_t *session, bool wait, slotid4 *slot,
 /**
  * @brief Release a reserved callback slot and wake waiters
  *
- * @param[in,out] session Session holding slot to release
+ * @param[in,out] session The session holding slot to release
  * @param[in]     slot    Slot to release
  * @param[in]     bool    Whether the operation was ever sent
  */
@@ -1382,7 +1382,7 @@ static int nfs_rpc_v40_single(nfs_client_id_t *clientid, nfs_cb_argop4 *op,
 /**
  * @brief Send CB_COMPOUND with a single operation
  *
- * In the case of v4.1+, this actually sends two opearations, a CB_SEQUENCE
+ * In the case of v4.1+, this actually sends two operations, a CB_SEQUENCE
  * and the supplied operation.  It works as a convenience function to handle
  * the details of callback management, finding a connection with a working
  * back channel, and so forth.
