@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * vim:noexpandtab:shiftwidth=8:tabstop=8:
  *
@@ -76,15 +77,10 @@ enum nfs_req_result nfs4_op_putrootfh(struct nfs_argop4 *op,
 	/* Clear out current entry for now */
 	set_current_entry(data, NULL);
 
-	/* Release any old export reference */
-	if (op_ctx->ctx_export != NULL)
-		put_gsh_export(op_ctx->ctx_export);
-
-	op_ctx->ctx_export = NULL;
-	op_ctx->fsal_export = NULL;
-
-	/* Get the root export of the Pseudo FS */
-	op_ctx->ctx_export = get_gsh_export_by_pseudo("/", true);
+	/* Get the root export of the Pseudo FS and release any old export
+	 * reference
+	 */
+	set_op_context_export(get_gsh_export_by_pseudo("/", true));
 
 	if (op_ctx->ctx_export == NULL) {
 		LogCrit(COMPONENT_EXPORT,
@@ -94,8 +90,6 @@ enum nfs_req_result nfs4_op_putrootfh(struct nfs_argop4 *op,
 		return NFS_REQ_ERROR;
 	}
 
-	op_ctx->fsal_export = op_ctx->ctx_export->fsal_export;
-
 	/* Build credentials */
 	res_PUTROOTFH4->status = nfs4_export_check_access(data->req);
 
