@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * vim:noexpandtab:shiftwidth=8:tabstop=8:
  *
@@ -356,8 +357,7 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 				PTHREAD_MUTEX_unlock(&grace_mutex);
 				nfs_release_v4_clients(gsp->ipaddr);
 				return ret;
-			}
-			else {
+			} else {
 				/*
 				 * If we're already in a grace period,
 				 * it can not break the existing count,
@@ -370,6 +370,8 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 			}
 		}
 	}
+	LogEvent(COMPONENT_STATE,
+		"grace reload client info completed from backend");
 out:
 	PTHREAD_MUTEX_unlock(&grace_mutex);
 	return ret;
@@ -462,7 +464,8 @@ int nfs_recovery_get_nodeid(char **pnodeid)
 	 */
 	maxlen = sysconf(_SC_HOST_NAME_MAX);
 	nodeid = gsh_malloc(maxlen);
-	rc = gethostname(nodeid, maxlen);
+	rc = gsh_gethostname(nodeid, maxlen,
+			nfs_param.core_param.enable_AUTHSTATS);
 	if (rc != 0) {
 		LogEvent(COMPONENT_CLIENTID, "gethostname failed: %d", errno);
 		rc = -errno;
@@ -489,7 +492,11 @@ void nfs_try_lift_grace(void)
 	 */
 	PTHREAD_MUTEX_lock(&grace_mutex);
 	rc_count = atomic_fetch_int32_t(&reclaim_completes);
+	LogEvent(COMPONENT_STATE, "check grace:reclaim complete(%d)"
+		" clid count(%d)", rc_count, clid_count);
+#ifdef _USE_NLM
 	if (!nfs_param.core_param.enable_NLM)
+#endif
 		in_grace = (rc_count != clid_count);
 
 	/* Otherwise, wait for the timeout */
@@ -1101,7 +1108,7 @@ restart:
 				PTHREAD_RWLOCK_unlock(&ht->partitions[i].lock);
 
 				/* nfs_client_id_expire requires cr_mutex
-				 * if not decoupled alread
+				 * if not decoupled already
 				 */
 				if (recp)
 					PTHREAD_MUTEX_lock(&recp->cr_mutex);
