@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * vim:noexpandtab:shiftwidth=8:tabstop=8:
  *
@@ -150,11 +151,14 @@ int compare_nsm_client(state_nsm_client_t *client1,
 	if (client1 == client2)
 		return 0;
 
-	if (!nfs_param.core_param.nsm_use_caller_name) {
-		if (client1->ssc_client != client2->ssc_client)
-			return 1;
-		return 0;
-	}
+	/* Since we always have a caller name in the key and records whether
+	 * nsm_use_caller_name is true or not, we don't ever compare ssc_client,
+	 * we always just compare the caller name.
+	 *
+	 * This makes SM_NOTIFY work because we can't know the port number
+	 * which is part of identifying ssc_client. We only care about the
+	 * address.
+	 */
 
 	if (client1->ssc_nlm_caller_name_len !=
 	    client2->ssc_nlm_caller_name_len)
@@ -196,21 +200,23 @@ uint32_t nsm_client_value_hash_func(hash_parameter_t *hparam,
 {
 	unsigned long res;
 	state_nsm_client_t *pkey = key->addr;
+	unsigned int sum = 0;
+	unsigned int i;
 
-	if (nfs_param.core_param.nsm_use_caller_name) {
-		unsigned int sum = 0;
-		unsigned int i;
+	/* Since we always have a caller name in the key and records whether
+	 * nsm_use_caller_name is true or not, we don't ever compare ssc_client,
+	 * we always just compare the caller name.
+	 *
+	 * This makes SM_NOTIFY work because we can't know the port number
+	 * which is part of identifying ssc_client. We only care about the
+	 * address.
+	 */
 
-		/* Compute the sum of all the characters */
-		for (i = 0; i < pkey->ssc_nlm_caller_name_len; i++)
-			sum += (unsigned char)pkey->ssc_nlm_caller_name[i];
+	/* Compute the sum of all the characters */
+	for (i = 0; i < pkey->ssc_nlm_caller_name_len; i++)
+		sum += (unsigned char)pkey->ssc_nlm_caller_name[i];
 
-		res =
-		    (unsigned long)sum +
-		    (unsigned long)pkey->ssc_nlm_caller_name_len;
-	} else {
-		res = (unsigned long) pkey->ssc_client;
-	}
+	res = (unsigned long)sum + (unsigned long)pkey->ssc_nlm_caller_name_len;
 
 	if (isDebug(COMPONENT_HASHTABLE))
 		LogFullDebug(COMPONENT_STATE, "value = %lu",
@@ -234,21 +240,23 @@ uint64_t nsm_client_rbt_hash_func(hash_parameter_t *hparam,
 {
 	unsigned long res;
 	state_nsm_client_t *pkey = key->addr;
+	unsigned int sum = 0;
+	unsigned int i;
 
-	if (nfs_param.core_param.nsm_use_caller_name) {
-		unsigned int sum = 0;
-		unsigned int i;
+	/* Since we always have a caller name in the key and records whether
+	 * nsm_use_caller_name is true or not, we don't ever compare ssc_client,
+	 * we always just compare the caller name.
+	 *
+	 * This makes SM_NOTIFY work because we can't know the port number
+	 * which is part of identifying ssc_client. We only care about the
+	 * address.
+	 */
 
-		/* Compute the sum of all the characters */
-		for (i = 0; i < pkey->ssc_nlm_caller_name_len; i++)
-			sum += (unsigned char)pkey->ssc_nlm_caller_name[i];
+	/* Compute the sum of all the characters */
+	for (i = 0; i < pkey->ssc_nlm_caller_name_len; i++)
+		sum += (unsigned char)pkey->ssc_nlm_caller_name[i];
 
-		res =
-		    (unsigned long)sum +
-		    (unsigned long)pkey->ssc_nlm_caller_name_len;
-	} else {
-		res = (unsigned long) pkey->ssc_client;
-	}
+	res = (unsigned long)sum + (unsigned long)pkey->ssc_nlm_caller_name_len;
 
 	if (isDebug(COMPONENT_HASHTABLE))
 		LogFullDebug(COMPONENT_STATE, "rbt = %lu", res);
@@ -702,15 +710,37 @@ int Init_nlm_hash(void)
  *
  * @param[in] client The client to ref
  */
-void inc_nsm_client_ref(state_nsm_client_t *client)
+void _inc_nsm_client_ref(state_nsm_client_t *client,
+			 char *file, int line, char *function)
 {
-	(void) atomic_inc_int32_t(&client->ssc_refcount);
+	char str[LOG_BUFF_LEN] = "\0";
+	struct display_buffer dspbuf = {sizeof(str), str, str};
+	bool strvalid = false;
+	int32_t refcount;
+
+	if (isFullDebug(COMPONENT_STATE)) {
+		display_nsm_client(&dspbuf, client);
+		strvalid = true;
+		/* Note that the way the logging below works, we will log at
+		 * FullDebug even if it is turned off in the middle of the
+		 * execution of this function since we don't test subsequently.
+		 */
+	}
+
+	refcount = atomic_inc_int32_t(&client->ssc_refcount);
+
+	if (strvalid) {
+		DisplayLogComponentLevel(
+			COMPONENT_STATE, file, line, function, NIV_FULL_DEBUG,
+			"Increment refcount now=%" PRId32 " {%s}",
+			refcount, str);
+	}
 }
 
 /**
  * @brief Free an NSM client
  *
- * @param[in] client Client to free
+ * @param[in] client The client to free
  */
 void free_nsm_client(state_nsm_client_t *client)
 {
@@ -729,7 +759,8 @@ void free_nsm_client(state_nsm_client_t *client)
  *
  * @param[in] client The client to release
  */
-void dec_nsm_client_ref(state_nsm_client_t *client)
+void _dec_nsm_client_ref(state_nsm_client_t *client,
+			char *file, int line, char *function)
 {
 	char str[LOG_BUFF_LEN] = "\0";
 	struct display_buffer dspbuf = {sizeof(str), str, str};
@@ -740,24 +771,34 @@ void dec_nsm_client_ref(state_nsm_client_t *client)
 	struct gsh_buffdesc old_value;
 	int32_t refcount;
 
-	if (isDebug(COMPONENT_STATE)) {
+	if (isFullDebug(COMPONENT_STATE)) {
 		display_nsm_client(&dspbuf, client);
 		str_valid = true;
+		/* Note that the way the logging below works, we will log at
+		 * FullDebug even if it is turned off in the middle of the
+		 * execution of this function since we don't test subsequently.
+		 */
 	}
 
 	refcount = atomic_dec_int32_t(&client->ssc_refcount);
 
 	if (refcount > 0) {
-		if (str_valid)
-			LogFullDebug(COMPONENT_STATE,
-				     "Decrement refcount now=%" PRId32 " {%s}",
-				     refcount, str);
+		if (str_valid) {
+			DisplayLogComponentLevel(
+				COMPONENT_STATE, file, line, function,
+				NIV_FULL_DEBUG,
+				"Decrement refcount now=%" PRId32 " {%s}",
+				refcount, str);
+		}
 
 		return;
 	}
 
-	if (str_valid)
-		LogFullDebug(COMPONENT_STATE, "Try to remove {%s}", str);
+	if (str_valid) {
+		DisplayLogComponentLevel(
+			COMPONENT_STATE, file, line, function, NIV_FULL_DEBUG,
+			"Try to remove {%s}", str);
+	}
 
 	buffkey.addr = client;
 	buffkey.len = sizeof(*client);
@@ -784,15 +825,23 @@ void dec_nsm_client_ref(state_nsm_client_t *client)
 		if (!str_valid)
 			display_nsm_client(&dspbuf, client);
 
-		LogCrit(COMPONENT_STATE, "Error %s, could not find {%s}",
-			hash_table_err_to_str(rc), str);
+		if (isLevel(COMPONENT_STATE, NIV_CRIT)) {
+			DisplayLogComponentLevel(
+				COMPONENT_STATE, file, line, function, NIV_CRIT,
+				"Error %s, could not find {%s}",
+				hash_table_err_to_str(rc), str);
+		}
 
 		return;
 	}
 
 	hashtable_releaselatched(ht_nsm_client, &latch);
 
-	LogFullDebug(COMPONENT_STATE, "Free {%s}", str);
+	if (str_valid) {
+		DisplayLogComponentLevel(
+			COMPONENT_STATE, file, line, function, NIV_FULL_DEBUG,
+			"Free {%s}", str);
+	}
 
 	nsm_unmonitor(client);
 	free_nsm_client(client);
@@ -802,13 +851,11 @@ void dec_nsm_client_ref(state_nsm_client_t *client)
  * @brief Get an NSM client
  *
  * @param[in] care        Care status
- * @param[in] xprt        RPC transport
  * @param[in] caller_name Caller name
  *
  * @return NSM client or NULL.
  */
-state_nsm_client_t *get_nsm_client(care_t care, SVCXPRT *xprt,
-				   char *caller_name)
+state_nsm_client_t *get_nsm_client(care_t care,  char *caller_name)
 {
 	state_nsm_client_t key;
 	state_nsm_client_t *pclient;
@@ -818,26 +865,57 @@ state_nsm_client_t *get_nsm_client(care_t care, SVCXPRT *xprt,
 	hash_error_t rc;
 	struct gsh_buffdesc buffkey;
 	struct gsh_buffdesc buffval;
+	char hostaddr_str[SOCK_NAME_MAX];
 
 	if (caller_name == NULL)
 		return NULL;
 
 	memset(&key, 0, sizeof(key));
 
-	if (nfs_param.core_param.nsm_use_caller_name) {
+	if (nfs_param.core_param.nsm_use_caller_name ||
+	    op_ctx->client == NULL) {
+		/* If nsm_use_caller_name is false but op_ctx->client is NULL
+		 * we are being called for SM_NOTIFY. caller name is supposed to
+		 * be an IP address.
+		 */
 		key.ssc_nlm_caller_name_len = strlen(caller_name);
 
 		if (key.ssc_nlm_caller_name_len > LM_MAXSTRLEN)
 			return NULL;
 
 		key.ssc_nlm_caller_name = caller_name;
-	} else if (op_ctx->client == NULL) {
-		LogCrit(COMPONENT_STATE,
-			"No gsh_client for caller_name %s", caller_name);
-
-		return NULL;
+		LogFullDebug(COMPONENT_STATE,
+			     "Using caller_name %s",
+			     caller_name);
 	} else {
-		key.ssc_nlm_caller_name = op_ctx->client->hostaddr_str;
+		sockaddr_t alt_host;
+		sockaddr_t *host = NULL;
+
+		if (isFullDebug(COMPONENT_STATE)) {
+			char str[LOG_BUFF_LEN] = "\0";
+			struct display_buffer db = {sizeof(str), str, str};
+
+			display_sockaddr(&db, op_ctx->caller_addr);
+			LogFullDebug(COMPONENT_STATE,
+				     "Using address %s as caller name",
+				     str);
+		}
+
+		/* Fixup any encapsulated IPv4 addresses */
+		host = convert_ipv6_to_ipv4(op_ctx->caller_addr, &alt_host);
+
+		/* Generate caller name from fixed up address */
+		if (!sprint_sockip(host, hostaddr_str, sizeof(hostaddr_str))) {
+			LogCrit(COMPONENT_STATE,
+				"Could not generate caller name");
+			return NULL;
+		}
+
+		LogFullDebug(COMPONENT_STATE,
+			     "Using caller address %s",
+			     hostaddr_str);
+
+		key.ssc_nlm_caller_name = hostaddr_str;
 		key.ssc_nlm_caller_name_len = strlen(key.ssc_nlm_caller_name);
 		key.ssc_client = op_ctx->client;
 	}
@@ -869,6 +947,8 @@ state_nsm_client_t *get_nsm_client(care_t care, SVCXPRT *xprt,
 
 		/* Return the found NSM Client */
 		if (isFullDebug(COMPONENT_STATE)) {
+			/* Clear out key and display found client */
+			display_reset_buffer(&dspbuf);
 			display_nsm_client(&dspbuf, pclient);
 			LogFullDebug(COMPONENT_STATE, "Found {%s}", str);
 		}
@@ -914,6 +994,7 @@ state_nsm_client_t *get_nsm_client(care_t care, SVCXPRT *xprt,
 
 	PTHREAD_MUTEX_init(&pclient->ssc_mutex, NULL);
 
+	/* Need deep copy of caller name */
 	pclient->ssc_nlm_caller_name = gsh_strdup(key.ssc_nlm_caller_name);
 
 	glist_init(&pclient->ssc_lock_list);
@@ -990,7 +1071,7 @@ void free_nlm_client(state_nlm_client_t *client)
 /**
  * @brief Take a reference on an NLM client
  *
- * @param[in] client Client to reference
+ * @param[in] client The client to reference
  */
 void inc_nlm_client_ref(state_nlm_client_t *client)
 {
@@ -1000,7 +1081,7 @@ void inc_nlm_client_ref(state_nlm_client_t *client)
 /**
  * @brief Relinquish a reference on an NLM client
  *
- * @param[in] client Client to release
+ * @param[in] client The client to release
  */
 void dec_nlm_client_ref(state_nlm_client_t *client)
 {
@@ -1097,7 +1178,7 @@ state_nlm_client_t *get_nlm_client(care_t care, SVCXPRT *xprt,
 	hash_error_t rc;
 	struct gsh_buffdesc buffkey;
 	struct gsh_buffdesc buffval;
-	struct sockaddr_storage local_addr;
+	sockaddr_t local_addr;
 	socklen_t addr_len;
 	uint32_t refcount;
 
@@ -1115,8 +1196,7 @@ state_nlm_client_t *get_nlm_client(care_t care, SVCXPRT *xprt,
 	    == -1) {
 		LogEvent(COMPONENT_CLIENTID, "Failed to get local addr.");
 	} else {
-		memcpy(&(key.slc_server_addr), &local_addr,
-		       sizeof(struct sockaddr_storage));
+		memcpy(&(key.slc_server_addr), &local_addr, sizeof(sockaddr_t));
 	}
 
 	if (key.slc_nlm_caller_name_len > LM_MAXSTRLEN)
