@@ -1,4 +1,5 @@
 #!/usr/bin/python3
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 # ganesha_mgr_utils.py - commandline tool utils for managing nfs-ganesha.
 #
@@ -20,20 +21,10 @@
 # Author: Allison Henderson <achender@vnet.linux.ibm.com>
 #-*- coding: utf-8 -*-
 
-try:
-    import gobject
-except ImportError:
-    from gi.repository import GObject as gobject
-
 import sys
-import dbus.mainloop.glib
 import dbus
-from dbus import glib
 from collections import namedtuple
 
-gobject.threads_init()
-glib.init_threads()
-
 Client = namedtuple('Client',
                     ['ClientIP',
                      'HasNFSv3',
